import { PropType } from 'vue';
import { VueNode } from '../_util/type';
import { RenderEmptyHandler } from '../config-provider/renderEmpty';
export interface CascaderOptionType {
    value?: string | number;
    label?: VueNode;
    disabled?: boolean;
    isLeaf?: boolean;
    loading?: boolean;
    children?: CascaderOptionType[];
    [key: string]: any;
}
export interface FieldNamesType {
    value?: string;
    label?: string;
    children?: string;
}
export interface FilledFieldNamesType {
    value: string;
    label: string;
    children: string;
}
export interface ShowSearchType {
    filter?: (inputValue: string, path: CascaderOptionType[], names: FilledFieldNamesType) => boolean;
    render?: (inputValue: string, path: CascaderOptionType[], prefixCls: string | undefined, names: FilledFieldNamesType) => VueNode;
    sort?: (a: CascaderOptionType[], b: CascaderOptionType[], inputValue: string, names: FilledFieldNamesType) => number;
    matchInputWidth?: boolean;
    limit?: number | false;
}
declare const Cascader: import("vue").DefineComponent<{
    /** 可选项数据源 */
    options: {
        type: PropType<CascaderOptionType[]>;
        default: any[];
    };
    /** 默认的选中项 */
    defaultValue: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    /** 指定选中项 */
    value: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    /** 选择完成后的回调 */
    /** 选择后展示的渲染函数 */
    displayRender: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    transitionName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    popupStyle: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    } & {
        default: () => {
            [key: string]: any;
        };
    };
    /** 自定义浮层类名 */
    popupClassName: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    /** 浮层预设位置：`bottomLeft` `bottomRight` `topLeft` `topRight` */
    popupPlacement: import("vue-types").VueTypeDef<"bottomRight" | "bottomLeft" | "topLeft" | "topRight"> & {
        default: "bottomRight" | "bottomLeft" | "topLeft" | "topRight";
    };
    /** 输入框占位文本*/
    placeholder: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    /** 输入框大小，可选 `large` `default` `small` */
    size: import("vue-types").VueTypeDef<"default" | "small" | "large">;
    /** 禁用*/
    disabled: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    /** 是否支持清除*/
    allowClear: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    showSearch: {
        type: PropType<boolean | ShowSearchType>;
        default: PropType<boolean | ShowSearchType>;
    };
    notFoundContent: import("vue-types").VueTypeValidableDef<VueNode>;
    loadData: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    /** 次级菜单的展开方式，可选 'click' 和 'hover' */
    expandTrigger: import("vue-types").VueTypeDef<"click" | "hover">;
    /** 当此项为 true 时，点选每级菜单选项值都会发生变化 */
    changeOnSelect: import("vue-types").VueTypeValidableDef<boolean>;
    /** 浮层可见变化时回调 */
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    inputPrefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    getPopupContainer: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    popupVisible: import("vue-types").VueTypeValidableDef<boolean>;
    fieldNames: {
        type: PropType<FieldNamesType>;
    };
    autofocus: import("vue-types").VueTypeValidableDef<boolean>;
    suffixIcon: import("vue-types").VueTypeValidableDef<VueNode>;
    showSearchRender: import("vue-types").VueTypeValidableDef<any>;
    onChange: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onPopupVisibleChange: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onFocus: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onBlur: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    onSearch: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    'onUpdate:value': import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
}, {
    configProvider: import("../config-provider").ConfigConsumerProps;
    localeData: any;
    cachedOptions: any[];
    popupRef: any;
    input: any;
}, {
    sValue: unknown[];
    inputValue: string;
    inputFocused: boolean;
    sPopupVisible: boolean;
    flattenOptions: any[];
}, {}, {
    savePopupRef(ref: any): void;
    highlightKeyword(str: string, keyword: string, prefixCls: string | undefined): (string | JSX.Element[])[];
    defaultRenderFilteredOption(opt: {
        inputValue: string;
        path: CascaderOptionType[];
        prefixCls: string | undefined;
        names: FilledFieldNamesType;
    }): any[];
    saveInput(node: any): void;
    handleChange(value: any, selectedOptions: CascaderOptionType[]): void;
    handlePopupVisibleChange(popupVisible: boolean): void;
    handleInputFocus(e: InputEvent): void;
    handleInputBlur(e: InputEvent): void;
    handleInputClick(e: MouseEvent & {
        nativeEvent?: any;
    }): void;
    handleKeyDown(e: KeyboardEvent): void;
    handleInputChange(e: Event): void;
    setValue(value: string[] | number[], selectedOptions?: CascaderOptionType[]): void;
    getLabel(): any;
    clearSelection(e: MouseEvent): void;
    generateFilteredOptions(prefixCls: string | undefined, renderEmpty: RenderEmptyHandler): {
        [x: string]: any;
        __IS_FILTERED_OPTION: boolean;
        path: CascaderOptionType[];
        disabled: boolean;
    }[] | {
        [x: string]: void | JSX.Element;
        disabled: boolean;
    }[];
    focus(): void;
    blur(): void;
}, {
    methods: {
        setState(state: {}, callback: any): void;
        __emit(...args: any[]): void;
    };
}, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    onFocus: (...args: any[]) => any;
    onBlur: (...args: any[]) => any;
    onChange: (...args: any[]) => any;
    prefixCls: string;
    getPopupContainer: (...args: any[]) => any;
    value: unknown[];
    disabled: boolean;
    options: CascaderOptionType[];
    placeholder: string;
    showSearch: boolean | ShowSearchType | (new (...args: any[]) => ShowSearchType & object) | ((new (...args: any[]) => ShowSearchType & object) | (() => boolean | ShowSearchType))[];
    onSearch: (...args: any[]) => any;
    transitionName: string;
    popupStyle: {
        [key: string]: any;
    };
    popupClassName: string;
    popupPlacement: "bottomRight" | "bottomLeft" | "topLeft" | "topRight";
    defaultValue: unknown[];
    allowClear: boolean;
    inputPrefixCls: string;
    "onUpdate:value": (...args: any[]) => any;
    displayRender: (...args: any[]) => any;
    loadData: (...args: any[]) => any;
    onPopupVisibleChange: (...args: any[]) => any;
} & {
    size?: "default" | "small" | "large";
    notFoundContent?: VueNode;
    autofocus?: boolean;
    popupVisible?: boolean;
    suffixIcon?: VueNode;
    expandTrigger?: "click" | "hover";
    changeOnSelect?: boolean;
    fieldNames?: unknown;
    showSearchRender?: any;
}>, {
    onFocus: (...args: any[]) => any;
    onBlur: (...args: any[]) => any;
    onChange: (...args: any[]) => any;
    prefixCls: string;
    getPopupContainer: (...args: any[]) => any;
    value: unknown[];
    disabled: boolean;
    options: CascaderOptionType[];
    placeholder: string;
    showSearch: boolean | ShowSearchType | (new (...args: any[]) => ShowSearchType & object) | ((new (...args: any[]) => ShowSearchType & object) | (() => boolean | ShowSearchType))[];
    onSearch: (...args: any[]) => any;
    transitionName: string;
    popupStyle: {
        [key: string]: any;
    };
    popupClassName: string;
    popupPlacement: "bottomRight" | "bottomLeft" | "topLeft" | "topRight";
    defaultValue: unknown[];
    allowClear: boolean;
    inputPrefixCls: string;
    "onUpdate:value": (...args: any[]) => any;
    displayRender: (...args: any[]) => any;
    loadData: (...args: any[]) => any;
    onPopupVisibleChange: (...args: any[]) => any;
}>;
export default Cascader;
